/*
 *  Copyright (C) 2000 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef __cplusplus
extern "C" {
#endif

#include <glade.h>

#include <gtk/gtkwindow.h>

gboolean dialog_ask_question (const gchar *question, GtkWidget *parent);
gboolean dialog_check_overwrite_file (const gchar *fname, GtkWidget *parent);
gboolean dialog_confirm_check (GtkWidget *parent, const gchar *dialogTitle,
			       const gchar *text, const gchar *checkMsg,
			       gboolean *checkValue);
void dialog_set_parent (GtkWidget *dialog, GtkWidget *parent_window);

#ifdef __cplusplus
}
#endif
